<template>
    <filter-dialog ref="table" :show.sync ='showDialog' :title="title" :tableData="tableData" :total="total"  :form="listQuery"  :formLabel="formLabel" @page-info-change="handPageInfoChange" :loading="loading">
        <template slot="condition">
              <el-button type="primary" size="mini" @click="handleFilter">查询</el-button>
              <el-button size="mini" @click="resetQuery">重置</el-button>
        </template>
        <template slot="columns">
            <el-table-column label="公司编码" prop="companyCode"></el-table-column>
            <el-table-column label="公司名称" prop="companyName"></el-table-column>
            <el-table-column label="公司类型" show-overflow-tooltip>
                <template slot-scope="scope">
                    {{getLabel(companyTypeArray,scope.row.companyType)}}
                </template>
            </el-table-column>
            <el-table-column label="操作">
                <template slot-scope="scope">
                     <wly-btn :type="'success'" @click="addRow(scope.row,scope.$index)">添加</wly-btn>
                </template>
            </el-table-column>
        </template>
    </filter-dialog>
</template>
<script>
import filterDialog from '@/components/filterDialog/filterDialog.vue'
import orderMgtApi from '@/api/orderMgt'
export default {
  components: { filterDialog },
  props: ['show', 'title'],
  data () {
    return {
      showDialog: false,
      listQuery: {
        companyCode: null,
        companyName: null
      },
      tableData: [],
      total: 0,
      loading: false,
      formLabel: [
        {
          model: 'companyCode',
          label: '公司编码',
          type: 'input'
        },
        {
          model: 'companyName',
          label: '公司名称',
          type: 'input'
        }
      ],
      companyTypeArray: [
        {
          name: '国内运输商',
          id: '1'
        },
        {
          name: ' 国际邮政',
          id: '2'
        },
        {
          name: '国际运输商',
          id: '3'
        }
      ]
    }
  },
  watch: {
    /**
     * 监控外部显示变量变化
     * 传递到dialog组件
     */
    show: function (newShow, oldShow) {
      this.showDialog = this.show
    },
    /**
     * 监控内部显示属性变化
     * 传递到外部调用变量
     */
    showDialog: function (newDialogShow, oldDialogShow) {
      this.$emit('update:show', newDialogShow)
      if (!newDialogShow) {
        this.$nextTick(() => {
          this.initForm() // 初始化表单
        })
      }
    }
  },
  methods: {
    /**
         * 获取数组的label
         */
    getLabel (array, id) {
      var lableText = array.find((item) => {
        return item.id === id
      })
      if (lableText) {
        return lableText.name
      }
      return ''
    },
    /**
     * 搜索条件变更处理
     */
    handleFilter () {
      this.$refs.table.changeCondition()
    },
    /**
     * 重置
     */
    resetQuery () {
      this.$refs.table.reloadCurrent()
    },
    /**
     * 初始化表单
     */
    initForm () {
      this.listQuery = {
        companyCode: null,
        companyName: null
      }
    },
    /**
       * 分页信息改变时,列表查询
       */
    handPageInfoChange (pageInfo) {
      this.queryList(pageInfo)
    },
    /**
       * 查询列表
       */
    queryList (pageInfo) {
      this.loading = true
      orderMgtApi.getExpressCompany({ ...this.listQuery, ...pageInfo }, false).then(res => {
        if (res.data) {
          this.tableData = res.data.list
          this.total = res.data.total
          this.loading = false
        } else {
          this.loading = false
        }
      }).catch(() => {
        this.loading = false
      })
    },
    addRow (row, index) {
      this.showDialog = false
      this.$emit('hand-selected-row-data', row)
    }
  }
}
</script>
